@@ -1,7 +1,7 @@
 import os
 import click
 
-from askanna.core import client
+from askanna.core.apiclient import client
 
 HELP = """
 Download manifest containing the commands for a run
@@ -15,7 +15,7 @@ SHORT_HELP = "Download manifest for run"
 )
 @click.command(help=HELP, short_help=SHORT_HELP)
 def cli(output):
-    api_server = client.config.remote
+    api_server = client.base_url
     run_suuid = os.getenv("AA_RUN_SUUID")
 
     download_url = "/".join(["runinfo", run_suuid, "manifest", ""])
