@@ -1,50 +1,26 @@
 import collections
 import datetime
-import glob
 import ipaddress
 import mimetypes
 import os
-from pathlib import Path
-import re
-import sys
-from typing import Any, List, Tuple, Dict
 import uuid
+from typing import Any, Dict, List, Tuple, Union
 from zipfile import ZipFile
 
 import click
 import croniter
-from email_validator import validate_email, EmailNotValidError
 import igittigitt
 import pytz
-import tzlocal
 import requests
-import yaml
-from yaml import load, dump
+from email_validator import EmailNotValidError, validate_email
+from tzlocal import get_localzone
 
 from askanna import __version__ as askanna_version
-from askanna.settings import (
-    CONFIG_FILE_ASKANNA,
-    CONFIG_ASKANNA_REMOTE,
-    DEFAULT_PROJECT_TEMPLATE,
-    PYPI_PROJECT_URL,
-)
+from askanna.settings import PYPI_PROJECT_URL
 
-try:
-    from yaml import CLoader as Loader, CDumper as Dumper
-except ImportError:
-    from yaml import Loader, Dumper
+StorageUnit = collections.namedtuple("StorageUnit", ["B", "KiB", "MiB", "GiB", "TiB", "PiB"])
 
-
-from askanna.core import exceptions
-
-
-StorageUnit = collections.namedtuple(
-    "StorageUnit", ["B", "KiB", "MiB", "GiB", "TiB", "PiB"]
-)
-
-diskunit = StorageUnit(
-    B=1, KiB=1024 ** 1, MiB=1024 ** 2, GiB=1024 ** 3, TiB=1024 ** 4, PiB=1024 ** 5
-)
+diskunit = StorageUnit(B=1, KiB=1024**1, MiB=1024**2, GiB=1024**3, TiB=1024**4, PiB=1024**5)
 
 supported_data_types = {
     # primitive types
@@ -68,10 +44,11 @@ except ImportError:
     numpy_available = False
 else:
     numpy_available = True
-    # list taken from https://numpy.org/doc/stable/user/basics.types.html
+    # Source Numpy documentation, a.o. https://numpy.org/doc/stable/user/basics.types.html
     numpy_types = {
         "numpy.bool_": "boolean",
         "numpy.intc": "integer",
+        "numpy.int": "integer",
         "numpy.int_": "integer",
         "numpy.uint": "integer",
         "numpy.short": "integer",
@@ -86,7 +63,14 @@ else:
         "numpy.csingle": "float",
         "numpy.cdouble": "float",
         "numpy.clongdouble": "float",
-        # more platform specific types
+        "numpy.str": "string",
+        "numpy.str_": "string",
+        # List type
+        "numpy.array": "list",
+        "numpy.ndarray": "list",
+        # C-derived names and more "complex" types
+        # Source: https://numpy.org/doc/stable/reference/arrays.scalars.html#sized-aliases
+        "numpy.bool8": "boolean",
         "numpy.int8": "integer",
         "numpy.int16": "integer",
         "numpy.int32": "integer",
@@ -100,12 +84,17 @@ else:
         "numpy.float32": "float",
         "numpy.float64": "float",
         "numpy.float_": "float",
-        # python equivalant of Decimal, convert to float now
         "numpy.complex64": "float",
         "numpy.complex128": "float",
+        "numpy.complex192": "float",
+        "numpy.complex256": "float",
         "numpy.complex_": "float",
-        # list type
-        "numpy.array": "list",
+        "numpy.longfloat": "float",
+        "numpy.singlecomplex": "float",
+        "numpy.cfloat": "float",
+        "numpy.longcomplex": "float",
+        "numpy.clongfloat": "float",
+        "numpy.unicode_": "string",
     }
     supported_data_types.update(**numpy_types)
 
@@ -150,144 +139,13 @@ def update_available() -> bool:
     if askanna_version == pypi_info["info"]["version"]:
         return False
     else:
-        click.echo(
-            "[INFO] A newer version of AskAnna is available. Update via: pip install -U askanna"
-        )
+        click.echo("[INFO] A newer version of AskAnna is available. Update via: pip install -U askanna")
         return True
 
 
-def check_for_project():
-    """
-    Performs a check if we are operating within a project folder. When
-    we wish to perform a deploy action, we want to be on the same
-    level with the `askanna.yml` to be able to package the file.
-    """
-    pyfiles = glob.glob("*.yml")
-
-    # look for the setup.py file
-    if "askanna.yml" in pyfiles:
-        return True
-    else:
-        return False
-
-
-def scan_config_in_path(cwd=None):
-    """
-    Look for askanna.yml in parent directories
-    """
-    if not cwd:
-        cwd = os.getcwd()
-    project_configfile = ""
-    # first check whether we already can find in the current workdir
-    if contains_configfile(cwd):
-        project_configfile = os.path.join(cwd, "askanna.yml")
-    else:
-        # traverse up all directories untill we find an askanna.yml file
-        split_path = os.path.split(cwd)
-        # in any other cases, look in parent directories
-        while split_path[1] != "":
-            if contains_configfile(split_path[0]):
-                project_configfile = os.path.join(split_path[0], "askanna.yml")
-                break
-            split_path = os.path.split(split_path[0])
-    return project_configfile
-
-
-def read_config(path: str) -> dict:
-    """
-    Reading existing config or return default dict
-    """
-    try:
-        with open(os.path.expanduser(path), "r") as f:
-            return load(f, Loader=Loader) or {}
-    except FileNotFoundError:
-        config_folder = os.path.dirname(CONFIG_FILE_ASKANNA)
-        if not os.path.exists(config_folder):
-            os.makedirs(config_folder, exist_ok=True)
-
-        Path(CONFIG_FILE_ASKANNA).touch()
-
-        # Write initial config if the config file didn't exist
-        config = store_config(CONFIG_ASKANNA_REMOTE)
-        with open(CONFIG_FILE_ASKANNA, "w") as f:
-            f.write(config)
-
-        return CONFIG_ASKANNA_REMOTE
-    except TypeError as e:
-        click.echo(e, err=True)
-        sys.exit(1)
-    except yaml.scanner.ScannerError as e:
-        click.echo("Error reading askanna.yml due to:", err=True)
-        click.echo(e.problem, err=True)
-        click.echo(e.problem_mark, err=True)
-        sys.exit(1)
-
-
-def contains_configfile(path: str, filename: str = "askanna.yml") -> bool:
-    return os.path.isfile(os.path.join(path, filename))
-
-
-def get_config(check_config=True) -> Dict:
-    config = read_config(CONFIG_FILE_ASKANNA)
-
-    # overwrite the AA remote if AA_REMOTE is set in the environment
-    is_remote_set = os.getenv("AA_REMOTE")
-    if is_remote_set:
-        config["askanna"] = config.get("askanna", {})
-        config["askanna"]["remote"] = is_remote_set
-
-    # if askanna remote is not set, add a default remote to the config file
-    try:
-        config["askanna"]["remote"]
-    except KeyError:
-        config = store_config(CONFIG_ASKANNA_REMOTE)
-        with open(CONFIG_FILE_ASKANNA, "w") as f:
-            f.write(config)
-        config = read_config(CONFIG_FILE_ASKANNA)
-
-    # overwrite the user token if AA_TOKEN is set in the environment
-    is_token_set = os.getenv("AA_TOKEN")
-    if is_token_set:
-        config["auth"] = config.get("auth", {})
-        config["auth"]["token"] = is_token_set
-
-    # set the project template
-    config["project"] = config.get("project", {})
-    config["project"]["template"] = os.getenv(
-        "PROJECT_TEMPLATE_URL", DEFAULT_PROJECT_TEMPLATE
-    )
-
-    project_config = scan_config_in_path()
-    if project_config:
-        config.update(**read_config(project_config))
-
-    if check_config:
-        validate_config(config)
-
-    return config
-
-
-def validate_config(config: Dict):
-    try:
-        config["auth"]["token"]
-    except KeyError:
-        click.echo(
-            "You are not logged in. Please login first via `askanna login`.", err=True
-        )
-        sys.exit(1)
-
-
-def store_config(new_config):
-    original_config = read_config(CONFIG_FILE_ASKANNA)
-    original_config.update(**new_config)
-    output = dump(original_config, Dumper=Dumper)
-    return output
-
-
 # Zip the files that matches the filter from given directory
 def zip_files_in_dir(directory_path: str, zip_file: ZipFile, ignore_file: str = None) -> None:
     files = get_files_in_dir(directory_path=directory_path, ignore_file=ignore_file)
-
     # Iterate over all the files and zip them
     for file in sorted(files):
         zip_file.write(file)
@@ -298,7 +156,7 @@ def get_files_in_dir(directory_path: str, ignore_file: str = None) -> set:
 
     ignore_parser = igittigitt.IgnoreParser()
     if ignore_file:
-        ignore_parser.parse_rule_files(os.path.dirname(ignore_file), ignore_file)
+        ignore_parser.parse_rule_files(os.path.dirname(ignore_file), os.path.basename(ignore_file))
 
     # Iterate over all the files in directory
     for root, _, files in os.walk(directory_path):
@@ -380,7 +238,7 @@ def create_zip_from_paths(filename: str, paths: List = []) -> None:
         zip_paths(paths, f, exclude_paths=exclude_paths)
 
 
-def _file_type(path):
+def file_type(path):
     """Mimic the type parameter of a JS File object.
     Resumable.js uses the File object's type attribute to guess mime type,
     which is guessed from file extention accoring to
@@ -399,36 +257,13 @@ def _file_type(path):
     return "" if type_ is None else type_
 
 
-def getProjectInfo(project_suuid):
-    # import the lib functions here, to prevent circular import
-    from askanna.core import client
-    from askanna.core.config import Config
-    from askanna.core.dataclasses import Project
-
-    config = Config()
-    r = client.get(
-        "{api_server}project/{project_suuid}/".format(
-            api_server=config.remote, project_suuid=project_suuid
-        ),
-    )
-
-    if r.status_code != 200:
-        raise exceptions.GetError(
-            "{} - Something went wrong while retrieving the "
-            "project info: {}".format(r.status_code, r.reason)
-        )
-
-    return Project(**r.json())
-
-
 def getProjectPackages(project, offset=0, limit=1):
-    from askanna.core import client
-    from askanna.core.config import Config
+    from askanna.config import config
+    from askanna.core.apiclient import client
 
-    config = Config()
     r = client.get(
-        "{api_server}project/{project_suuid}/packages/?offset={offset}&limit={limit}".format(
-            api_server=config.remote,
+        "{api_server}/v1/project/{project_suuid}/packages/?offset={offset}&limit={limit}".format(
+            api_server=config.server.remote,
             project_suuid=project.short_uuid,
             offset=offset,
             limit=limit,
@@ -440,21 +275,6 @@ def getProjectPackages(project, offset=0, limit=1):
     return r.json()
 
 
-def extract_push_target(push_target: str):
-    """
-    Extract push target from the url configured
-    Workspace is optional
-    """
-    if not push_target:
-        raise ValueError("Cannot extract push-target if push-target is not set.")
-    match_pattern = re.compile(
-        r"(?P<http_scheme>https|http):\/\/(?P<askanna_host>[\w\.\-\:]+)\/(?P<workspace_suuid>[\w-]+){0,1}\/{0,1}project\/(?P<project_suuid>[\w-]+)\/{0,1}"  # noqa: E501
-    )
-    matches = match_pattern.match(push_target)
-    matches_dict = matches.groupdict()
-    return matches_dict
-
-
 def validate_cron_line(cron_line: str) -> bool:
     """
     We validate the cron expression with croniter
@@ -534,9 +354,7 @@ def validate_yml_job_names(config):
         "worker",
     )
 
-    overlapping_with_reserved_keys = list(
-        set(config.keys()).intersection(set(reserved_keys))
-    )
+    overlapping_with_reserved_keys = list(set(config.keys()).intersection(set(reserved_keys)))
     for overlap_key in overlapping_with_reserved_keys:
         is_dict = isinstance(config.get(overlap_key), dict)
         is_job = is_dict and config.get(overlap_key).get("job")
@@ -691,8 +509,7 @@ def validate_askanna_yml(config):
     if global_timezone:
         if global_timezone not in pytz.all_timezones:
             click.echo(
-                "Invalid timezone setting found in askanna.yml:\n"
-                + f"timezone: {global_timezone}",
+                "Invalid timezone setting found in askanna.yml:\n" + f"timezone: {global_timezone}",
                 err=True,
             )
             return False
@@ -735,8 +552,7 @@ def validate_askanna_yml(config):
             timezone = job.get("timezone")
             if timezone and timezone not in pytz.all_timezones:
                 click.echo(
-                    f"Invalid timezone setting found in job `{jobname}`:\n"
-                    + f"timezone: {timezone}",
+                    f"Invalid timezone setting found in job `{jobname}`:\n" + f"timezone: {timezone}",
                     err=True,
                 )
                 return False
@@ -753,7 +569,7 @@ def validate_askanna_yml(config):
                         return False
 
                 if not timezone and not global_timezone and not timezone_checked:
-                    timezone_local = getLocalTimezone()
+                    timezone_local = get_localzone()
                     if timezone_local != "UTC":
                         click.echo(  # noqa
                             f"""
@@ -848,8 +664,37 @@ def translate_dtype(value: Any) -> str:
     Return the full name of the type, if not listed, return the typename from the input
     """
     typename = object_fullname(value)
+    dtype = supported_data_types.get(typename, typename)
 
-    return supported_data_types.get(typename, typename)
+    if typename in ("numpy.array", "numpy.ndarray"):
+        dtype_list = supported_data_types.get("numpy." + value.dtype.name)
+        if dtype_list:
+            dtype = "list_" + dtype_list
+    elif typename == "list":
+        dtype_list = None
+        for val in value:
+            if type(val) == bool and dtype_list in (None, "boolean"):
+                dtype_list = "boolean"
+            elif type(val) == int and dtype_list in (None, "integer"):
+                dtype_list = "integer"
+            elif type(val) in (int, float) and dtype_list in (None, "integer", "float"):
+                dtype_list = "float"
+            elif type(val) == str and dtype_list in (None, "string"):
+                dtype_list = "string"
+            elif type(val) == datetime.datetime and dtype_list in (None, "datetime"):
+                dtype_list = "datetime"
+            elif type(val) == datetime.time and dtype_list in (None, "time"):
+                dtype_list = "time"
+            elif type(val) == datetime.date and dtype_list in (None, "date"):
+                dtype_list = "date"
+            else:
+                dtype_list = "mixed"
+                break
+
+        if dtype_list and dtype_list != "mixed":
+            dtype = "list_" + dtype_list
+
+    return dtype
 
 
 def validate_value(value: Any) -> bool:
@@ -885,17 +730,20 @@ def prepare_and_validate_value(value: Any) -> Tuple[Any, bool]:
     return value, False
 
 
-def labels_to_type(label: Any = None, labelclass=collections.namedtuple) -> List:
+def labels_to_type(label: Union[str, list, dict] = "", labelclass=collections.namedtuple) -> List:
     # process labels
     labels = []
 
+    if not label:
+        return labels
+
     # test label type, if it is a string, then convert it to tag
     if isinstance(label, str):
         labels.append(labelclass(name=label, value=None, dtype="tag"))
     elif isinstance(label, list):
         for name in label:
             labels.append(labelclass(name=name, value=None, dtype="tag"))
-    elif label:
+    elif isinstance(label, dict):
         for k, v in label.items():
             if v is None:
                 labels.append(labelclass(name=k, value=None, dtype="tag"))
@@ -903,9 +751,7 @@ def labels_to_type(label: Any = None, labelclass=collections.namedtuple) -> List
                 if v:
                     v, valid = prepare_and_validate_value(v)
                     if valid:
-                        labels.append(
-                            labelclass(name=k, value=v, dtype=translate_dtype(v))
-                        )
+                        labels.append(labelclass(name=k, value=v, dtype=translate_dtype(v)))
                     else:
                         click.echo(
                             f"AskAnna cannot store this datatype. Label {k} with value {v} not stored.",
@@ -922,13 +768,6 @@ def isIPAddress(ip: str) -> bool:
     return True
 
 
-def getLocalTimezone() -> str:
-    """
-    Determine the local timezone name
-    """
-    return tzlocal.get_localzone().zone
-
-
 def content_type_file_extension(content_type: str) -> str:
     content_type_file_extension_mapping = {
         "application/csv": ".csv",
@@ -946,3 +785,18 @@ def content_type_file_extension(content_type: str) -> str:
     file_extension = content_type_file_extension_mapping.get(content_type, ".unknown")
 
     return file_extension
+
+
+def value_not_empty(value: Any) -> bool:
+    """
+    Check if the value is not empty
+    """
+    if value.__class__.__module__ == "numpy":
+        try:
+            if value.any() or isinstance(value, np.bool_):
+                return True
+        except np.core._exceptions.UFuncTypeError:
+            pass
+    if value or isinstance(value, bool):
+        return True
+    return False
