@@ -6,7 +6,6 @@
 import click
 
 from askanna import USING_ASKANNA_CLI
-from askanna.core.config import Config
 from askanna.core.job import JobGateway
 from askanna.core.metrics import track_metric, track_metrics, MetricGateway  # noqa
 from askanna.core.variables_tracked import track_variable, track_variables  # noqa
@@ -23,7 +22,6 @@ if USING_ASKANNA_CLI:
     except Exception as e:
         click.echo(f"Something went wrong while checking if an update is available: {e}", err=True)
 
-config = Config()
 
 # Instantiated objects for query or actions, these do not contain any data on load and will be filled with data on
 # using detail/get/list actions from it.
